@@ -543,7 +543,7 @@ show_chapter_edit_dialog (TotemChaptersPlugin	*plugin)
 	g_object_get (G_OBJECT (plugin->priv->totem), "current-time", &_time, NULL);
 	if (G_UNLIKELY (!check_available_time (plugin, _time))) {
 		totem_interface_error_blocking (_("Chapter with the same time already exists"),
-						_("Try another name or remove an existing chapter"),
+						_("Try another name or remove an existing chapter."),
 						main_window);
 		g_object_unref (main_window);
 		if (plugin->priv->was_played)
@@ -842,9 +842,8 @@ save_button_clicked_cb (GtkButton		*button,
 
 	if (G_UNLIKELY (totem_cmml_write_file_async (data) < 0)) {
 		totem_action_error (plugin->priv->totem, _("Error occurred while saving chapters"),
-				    _("Please check you rights and free space"));
+		                    _("Please check you have permission to write to the folder containing the movie."));
 		g_free (data);
-		g_object_unref (plugin->priv->cancellable);
 	} else
 		gtk_widget_set_sensitive (plugin->priv->save_button, FALSE);
 }
@@ -976,7 +975,7 @@ load_button_clicked_cb (GtkButton		*button,
 
 	mrl = totem_get_current_mrl (plugin->priv->totem);
 	main_window = totem_get_main_window (plugin->priv->totem);
-	dialog = gtk_file_chooser_dialog_new (_("Open Chapters File"), main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
+	dialog = gtk_file_chooser_dialog_new (_("Open Chapter File"), main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					      NULL);
@@ -1093,7 +1092,7 @@ impl_activate (PeasActivatable *plugin)
 	g_object_ref (cplugin->priv->ui_manager);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
-	column = gtk_tree_view_column_new_with_attributes ("Pixbuf", renderer, "pixbuf", CHAPTERS_PIXBUF_COLUMN, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Chapter Screenshot"), renderer, "pixbuf", CHAPTERS_PIXBUF_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (cplugin->priv->tree), column);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -1104,7 +1103,7 @@ impl_activate (PeasActivatable *plugin)
 	g_signal_connect (G_OBJECT (renderer), "edited",
 			  G_CALLBACK (finish_chapter_edit), cplugin);
 
-	column = gtk_tree_view_column_new_with_attributes ("Title", renderer,
+	column = gtk_tree_view_column_new_with_attributes (_("Chapter Title"), renderer,
 							   "markup", CHAPTERS_TITLE_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (cplugin->priv->tree), column);
 
@@ -1174,6 +1173,37 @@ impl_deactivate (PeasActivatable *plugin)
 	totem = g_object_get_data (G_OBJECT (plugin), "object");
 	cplugin = TOTEM_CHAPTERS_PLUGIN (plugin);
 
+	/* If there are unsaved changes to the chapter data, ask the user if they'd like to save them. */
+	if (gtk_widget_get_sensitive (cplugin->priv->save_button) == TRUE) {
+		GtkWidget *dialog;
+		GtkWindow *main_window;
+
+		main_window = totem_object_get_main_window (totem);
+		dialog = gtk_message_dialog_new (main_window, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		                                 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+		                                 _("Save changes to chapter list before closing?"));
+		g_object_unref (main_window);
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+		                        /* Translators: close Totem without saving changes to the chapter list of the current movie. */
+		                        _("Close without Saving"), GTK_RESPONSE_CLOSE,
+		                        /* Translators: save changes to the chapter list of the current movie before closing Totem. */
+		                        _("Save"), GTK_RESPONSE_OK,
+		                        NULL);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		                                          _("If you don't save, changes to the chapter list will be lost."));
+
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+			/* Save the chapter list before closing */
+			save_button_clicked_cb (GTK_BUTTON (cplugin->priv->save_button), cplugin);
+
+			/* Prevent it being cancelled further down in this function */
+			cplugin->priv->cancellable[1] = NULL;
+		}
+
+		gtk_widget_destroy (dialog);
+	}
+
 	/* FIXME: do not cancel async operation if any */
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
